@@ -1,4 +1,4 @@
-use crossterm::{cursor::position, terminal};
+use crossterm::terminal;
 use std::io::{self, ErrorKind};
 
 /// The size of the terminal window.
@@ -88,14 +88,6 @@ pub(crate) struct CursorPosition {
     pub(crate) row: u16,
 }
 
-impl CursorPosition {
-    /// Get the current cursor position.
-    pub(crate) fn current() -> io::Result<Self> {
-        let (column, row) = position()?;
-        Ok(Self { column, row })
-    }
-}
-
 #[cfg(test)]
 mod test {
     use super::*;
